<?php

namespace Drupal\layout_section_classes;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Layout\LayoutDefault;
use Drupal\Core\Plugin\PluginFormInterface;

/**
 * A layout plugin class for layouts with selectable classes.
 */
class ClassyLayout extends LayoutDefault implements PluginFormInterface {

  /**
   * {@inheritdoc}
   */
  public function build(array $regions) {
    $build = parent::build($regions);
    if ($classes = $this->configuration['classes']) {
      $build['#attributes']['classes'][] = $classes;
    }
    return $build;
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $options[''] = $this->t('- None -');
    $options += $this->getPluginDefinition()->get('classes');
    $form['classes'] = [
      '#title' => $this->t('Region style'),
      '#type' => 'select',
      '#options' => $options,
      '#default_value' => $this->configuration['classes'],
      '#description' => $this->t('Select the style that will be applied to this region.'),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateConfigurationForm(array &$form, FormStateInterface $form_state) {
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return parent::defaultConfiguration() + [
      'classes' => '',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    if ($classes = $form_state->getValue('classes')) {
      $this->configuration['classes'] = $classes;
    }
  }

}
